@@ -6,7 +6,7 @@ from nose.tools import *
 from StringIO import StringIO
 
 # functions for test
-from ikazuchi.izuchi.handler import *
+from ikazuchi.core.handler import *
 
 
 class TestPOFileHandler(object):
@@ -31,7 +31,7 @@ class TestPOFileHandler(object):
             (["ref", "cur", "ent"], "ent"),
             (["ref", "", "ent"], "ent"),
         ]
-        h = POFileHandler(self.po_file.name, ["utf-8", "utf-8"])
+        h = POFileHandler("google", self.po_file.name, ["utf-8", "utf-8"])
         for d in data:
             assert_equals(d[1], h._select_translation(*d[0]))
 
@@ -39,7 +39,8 @@ class TestPOFileHandler(object):
 class TestSingleSentenceHandler(object):
 
     class Option(object):
-        sentence = ""
+        api = "google"
+        sentences = [""]
         encoding = ["utf-8", "utf-8"]
         quiet = False
         detect = False
@@ -49,7 +50,7 @@ class TestSingleSentenceHandler(object):
         self.opts = TestSingleSentenceHandler.Option()
 
     def _dummy_translate(self, sentence):
-        yield "", sentence
+        return "", sentence
 
     def test_with_quiet_option(self):
         self.opts.quiet = True
